@@ -517,42 +517,38 @@ VkResult Fence::reset() {
     return vk::ResetFences(device(), 1, &fence);
 }
 
-VkResult Fence::export_handle(Fence::ExternalHandle &ext_handle, VkExternalFenceHandleTypeFlagBits handle_type) {
-#ifdef _WIN32
+#ifdef VK_USE_PLATFORM_WIN32_KHR
+VkResult Fence::export_handle(HANDLE &win32_handle, VkExternalFenceHandleTypeFlagBits handle_type) {
     auto ghi = LvlInitStruct<VkFenceGetWin32HandleInfoKHR>();
     ghi.fence = handle();
     ghi.handleType = handle_type;
-    auto vkGetFenceWin32HandleKHR = (PFN_vkGetFenceWin32HandleKHR)vk::GetDeviceProcAddr(device(), "vkGetFenceWin32HandleKHR");
-    return vkGetFenceWin32HandleKHR(device(), &ghi, &ext_handle);
-#else
-    auto gfi = LvlInitStruct<VkFenceGetFdInfoKHR>();
-    gfi.fence = handle();
-    gfi.handleType = handle_type;
-    auto vkGetFenceFdKHR = (PFN_vkGetFenceFdKHR)vk::GetDeviceProcAddr(device(), "vkGetFenceFdKHR");
-    return vkGetFenceFdKHR(device(), &gfi, &ext_handle);
-#endif
+    return vk::GetFenceWin32HandleKHR(device(), &ghi, &win32_handle);
 }
 
-VkResult Fence::import_handle(Fence::ExternalHandle ext_handle, VkExternalFenceHandleTypeFlagBits handle_type,
-                              VkFenceImportFlags flags) {
-#ifdef _WIN32
+VkResult Fence::import_handle(HANDLE win32_handle, VkExternalFenceHandleTypeFlagBits handle_type, VkFenceImportFlags flags) {
     auto ifi = LvlInitStruct<VkImportFenceWin32HandleInfoKHR>();
     ifi.fence = handle();
     ifi.handleType = handle_type;
-    ifi.handle = ext_handle;
+    ifi.handle = win32_handle;
     ifi.flags = flags;
-    auto vkImportFenceWin32HandleKHR =
-        reinterpret_cast<PFN_vkImportFenceWin32HandleKHR>(vk::GetDeviceProcAddr(device(), "vkImportFenceWin32HandleKHR"));
-    return vkImportFenceWin32HandleKHR(device(), &ifi);
-#else
+    return vk::ImportFenceWin32HandleKHR(device(), &ifi);
+}
+#endif  // VK_USE_PLATFORM_WIN32_KHR
+
+VkResult Fence::export_handle(int &fd_handle, VkExternalFenceHandleTypeFlagBits handle_type) {
+    auto gfi = LvlInitStruct<VkFenceGetFdInfoKHR>();
+    gfi.fence = handle();
+    gfi.handleType = handle_type;
+    return vk::GetFenceFdKHR(device(), &gfi, &fd_handle);
+}
+
+VkResult Fence::import_handle(int fd_handle, VkExternalFenceHandleTypeFlagBits handle_type, VkFenceImportFlags flags) {
     auto ifi = LvlInitStruct<VkImportFenceFdInfoKHR>();
     ifi.fence = handle();
     ifi.handleType = handle_type;
-    ifi.fd = ext_handle;
+    ifi.fd = fd_handle;
     ifi.flags = flags;
-    auto vkImportFenceFdKHR = reinterpret_cast<PFN_vkImportFenceFdKHR>(vk::GetDeviceProcAddr(device(), "vkImportFenceFdKHR"));
-    return vkImportFenceFdKHR(device(), &ifi);
-#endif
+    return vk::ImportFenceFdKHR(device(), &ifi);
 }
 
 NON_DISPATCHABLE_HANDLE_DTOR(Semaphore, vk::DestroySemaphore)
@@ -561,49 +557,42 @@ void Semaphore::init(const Device &dev, const VkSemaphoreCreateInfo &info) {
     NON_DISPATCHABLE_HANDLE_INIT(vk::CreateSemaphore, dev, &info);
 }
 
-VkResult Semaphore::export_handle(Semaphore::ExternalHandle &ext_handle, VkExternalSemaphoreHandleTypeFlagBits handle_type) {
-#ifdef _WIN32
-    ext_handle = nullptr;
+#ifdef VK_USE_PLATFORM_WIN32_KHR
+VkResult Semaphore::export_handle(HANDLE &win32_handle, VkExternalSemaphoreHandleTypeFlagBits handle_type) {
+    win32_handle = nullptr;
     auto ghi = LvlInitStruct<VkSemaphoreGetWin32HandleInfoKHR>();
     ghi.semaphore = handle();
     ghi.handleType = handle_type;
-    auto vkGetSemaphoreWin32HandleKHR =
-        reinterpret_cast<PFN_vkGetSemaphoreWin32HandleKHR>(vk::GetDeviceProcAddr(device(), "vkGetSemaphoreWin32HandleKHR"));
-    return vkGetSemaphoreWin32HandleKHR(device(), &ghi, &ext_handle);
-#else
-    ext_handle = -1;
-    auto ghi = LvlInitStruct<VkSemaphoreGetFdInfoKHR>();
-    ghi.semaphore = handle();
-    ghi.handleType = handle_type;
-    auto vkGetSemaphoreFdKHR = reinterpret_cast<PFN_vkGetSemaphoreFdKHR>(vk::GetDeviceProcAddr(device(), "vkGetSemaphoreFdKHR"));
-    return vkGetSemaphoreFdKHR(device(), &ghi, &ext_handle);
-#endif
+    return vk::GetSemaphoreWin32HandleKHR(device(), &ghi, &win32_handle);
 }
 
-VkResult Semaphore::import_handle(Semaphore::ExternalHandle ext_handle, VkExternalSemaphoreHandleTypeFlagBits handle_type,
+VkResult Semaphore::import_handle(HANDLE win32_handle, VkExternalSemaphoreHandleTypeFlagBits handle_type,
                                   VkSemaphoreImportFlags flags) {
-#ifdef _WIN32
     auto ihi = LvlInitStruct<VkImportSemaphoreWin32HandleInfoKHR>();
     ihi.semaphore = handle();
     ihi.handleType = handle_type;
-    ihi.handle = ext_handle;
+    ihi.handle = win32_handle;
     ihi.flags = flags;
+    return vk::ImportSemaphoreWin32HandleKHR(device(), &ihi);
+}
+#endif  // VK_USE_PLATFORM_WIN32_KHR
 
-    auto vkImportSemaphoreWin32HandleKHR =
-        reinterpret_cast<PFN_vkImportSemaphoreWin32HandleKHR>(vk::GetDeviceProcAddr(device(), "vkImportSemaphoreWin32HandleKHR"));
-    return vkImportSemaphoreWin32HandleKHR(device(), &ihi);
-#else
+VkResult Semaphore::export_handle(int &fd_handle, VkExternalSemaphoreHandleTypeFlagBits handle_type) {
+    fd_handle = -1;
+    auto ghi = LvlInitStruct<VkSemaphoreGetFdInfoKHR>();
+    ghi.semaphore = handle();
+    ghi.handleType = handle_type;
+    return vk::GetSemaphoreFdKHR(device(), &ghi, &fd_handle);
+}
+
+VkResult Semaphore::import_handle(int fd_handle, VkExternalSemaphoreHandleTypeFlagBits handle_type, VkSemaphoreImportFlags flags) {
     // Import opaque handle exported above
     auto ihi = LvlInitStruct<VkImportSemaphoreFdInfoKHR>();
     ihi.semaphore = handle();
     ihi.handleType = handle_type;
-    ihi.fd = ext_handle;
+    ihi.fd = fd_handle;
     ihi.flags = flags;
-
-    auto vkImportSemaphoreFdKHR =
-        reinterpret_cast<PFN_vkImportSemaphoreFdKHR>(vk::GetDeviceProcAddr(device(), "vkImportSemaphoreFdKHR"));
-    return vkImportSemaphoreFdKHR(device(), &ihi);
-#endif
+    return vk::ImportSemaphoreFdKHR(device(), &ihi);
 }
 
 NON_DISPATCHABLE_HANDLE_DTOR(Event, vk::DestroyEvent)
@@ -668,6 +657,12 @@ VkMemoryRequirements Buffer::memory_requirements() const {
     return reqs;
 }
 
+void Buffer::allocate_and_bind_memory(const Device &dev, VkMemoryPropertyFlags mem_props, void *alloc_info_pnext) {
+    assert(!internal_mem_.initialized());
+    internal_mem_.init(dev, DeviceMemory::get_resource_alloc_info(dev, memory_requirements(), mem_props, alloc_info_pnext));
+    bind_memory(internal_mem_, 0);
+}
+
 void Buffer::bind_memory(const DeviceMemory &mem, VkDeviceSize mem_offset) {
     const auto result = vk::BindBufferMemory(device(), handle(), mem.handle(), mem_offset);
     // Allow successful calls and the calls that cause validation errors (but not actual Vulkan errors).
@@ -675,14 +670,7 @@ void Buffer::bind_memory(const DeviceMemory &mem, VkDeviceSize mem_offset) {
     EXPECT(result == VK_SUCCESS || result == VK_ERROR_VALIDATION_FAILED_EXT);
 }
 
-void Buffer::bind_memory(const Device &dev, VkMemoryPropertyFlags mem_props, VkDeviceSize mem_offset) {
-    if (!internal_mem_.initialized()) {
-        internal_mem_.init(dev, DeviceMemory::get_resource_alloc_info(dev, memory_requirements(), mem_props));
-    }
-    bind_memory(internal_mem_, mem_offset);
-}
-
-VkDeviceAddress Buffer::address(uint32_t vk_api_version /*= VK_API_VERSION_1_2*/) const {
+VkDeviceAddress Buffer::address(APIVersion vk_api_version /*= VK_API_VERSION_1_2*/) const {
     auto bdai = LvlInitStruct<VkBufferDeviceAddressInfo>();
     bdai.buffer = handle();
     if (vk_api_version < VK_API_VERSION_1_2) {
@@ -743,6 +731,12 @@ VkMemoryRequirements Image::memory_requirements() const {
     return reqs;
 }
 
+void Image::allocate_and_bind_memory(const Device &dev, VkMemoryPropertyFlags mem_props, void *alloc_info_pnext) {
+    assert(!internal_mem_.initialized());
+    internal_mem_.init(dev, DeviceMemory::get_resource_alloc_info(dev, memory_requirements(), mem_props, alloc_info_pnext));
+    bind_memory(internal_mem_, 0);
+}
+
 void Image::bind_memory(const DeviceMemory &mem, VkDeviceSize mem_offset) {
     const auto result = vk::BindImageMemory(device(), handle(), mem.handle(), mem_offset);
     // Allow successful calls and the calls that cause validation errors (but not actual Vulkan errors).
